@@ -25,14 +25,10 @@ public:
     virtual bool reboot();
     virtual bool lockScreen();
     virtual bool logout();
-    virtual bool activateAction( int id );
-    virtual int registerTask( const QString& name, const QString& description, int action );
-    virtual bool unregisterTask( int id );
     virtual ASYNC configure();
     virtual QString getStatusInfo();
     virtual ASYNC makeVisible();
     virtual ASYNC setTestMode( bool yes );
-    virtual ASYNC wizard();
 protected:
     KShutdownIface_stub() : DCOPStub( never_use ) {};
 };
